Volg hoe vaak personen, bedrijven of plaatsen in de loop van de tijd samen voorkomen
Volg hoe vaak personen, bedrijven of plaatsen in de loop van de tijd samen voorkomen. Kijk of de berichtgeving positief, negatief of neutraal is en filter op bron
Invoerparameters
| Parameter | Beschrijving | Type | Standaard | Vereist |
|---|---|---|---|---|
| entity.id | Meerdere entiteits-ID's, gescheiden door komma's. | string | Ja | |
| published_at.start | Startdatum voor tijdsbereik. | string | Ja | |
| published_at.end | Einddatum voor tijdsbereik. | string | Ja | |
| sort.by | Sorteren op sentiment score. | string | Ja | |
| sort.order | Aflopende volgorde. | string | Ja | |
| is_duplicate | Duplicaten uitsluiten. | integer | 0 | Ja |
| api_key | Uw API sleutel | string | Ja | |
| per_page | Maximaal aantal op te halen artikelen | integer | 50 | Nee |
Workflow-voorbeelden
Bekijk welke personen, organisaties en locaties samen in artikelen voorkomen:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Volg vermeldingen van een persoon, organisatie of plaats in de loop van de tijd:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&published_at.start=2022-01-01&published_at.end=2023-12-31&per_page=100&sort.by=published_at&sort.order=asc&api_key=YOUR_API_KEY"
Bekijk welke personen, organisaties en locaties samen worden genoemd:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&organization.name=Tesla&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=published_at&api_key=YOUR_API_KEY"
Kijk hoe een persoon, organisatie of plaats van invloed is op de positieve, negatieve of neutrale marktdekking:
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&category.id=medtop:04000000&sentiment.overall.score.min=0.7&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Gerelateerde voorbeelden
- Vind met welke organisaties een persoon wordt genoemd
- Merkreputatieanalyse
- Volg uw concurrenten
- Filter artikelen waarin personen worden genoemd
- Sorteer op engagementscore
Recept voor cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50' \
--header 'Content-Type: application/json'
Recept voor Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Recept voor Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Recept voor PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'entity.id' => '1278268,1282301',
'published_at.start' => '2023-01-01',
'published_at.end' => '2023-12-31',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'is_duplicate' => 0,
'api_key' => 'YOUR_API_KEY',
'per_page' => 50,
],
]);
echo $response->getBody();
Recept voor Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();